@@ -1,4 +1,5 @@
 import requests
+from requests.api import request
 import typer
 import toml
 from pathlib import Path
@@ -16,9 +17,9 @@ class toml_helper():
                 return r
         except FileNotFoundError:
             if verbose:
-                typer.echo("File not found.")
+                typer.secho("File not found.", err= True, fg='yellow')
         except toml.TomlDecodeError:
-            typer.echo("File encoding error.")
+            typer.secho("File encoding error.", err= True, fg='yellow')
         
         return {}
     
@@ -42,6 +43,12 @@ class toml_helper():
         except:
             return []
 
+    def get_db_prop(database):
+        try:
+            r = toml_helper.get_dict(toml_helper.config_file).get("databases").get(database)["properties"]
+            return r
+        except:
+            return []
 
 class api_helper():
     api_url_pre = "https://api.notion.com/v1/"
@@ -52,8 +59,21 @@ class api_helper():
         "Content-Type": "application/json"
     }
 
+    def get_db_props(self, database):
+        r = self.get_database(self, database)
 
-   
+        try:   
+            r = r.get("properties")
+            if type(r) is dict:
+                return r.keys()
+            else:
+                return []
+        except:
+            typer.echo(r)
+            return []
+
+    def get_database(self, database):
+        return self.api(self, requests.get, "databases/" + database, "")
 
     
     def new_page(self, title, database):
@@ -85,8 +105,8 @@ class api_helper():
             if (r.status_code == 200):
                 return r.json()
             else:
-                typer.echo("Request post error")
+                typer.secho("Request post error", err= True, fg='yellow')
                 return ""
         except:
-            typer.echo("Request post error")
+            typer.secho("Request post error", err= True, fg='yellow')
             return ""
